==> mysql-5.7.37.tar.gz: mysql-5.7.37/client/dump/abstract_simple_dump_task.h <==
/*
  Copyright (c) 2015, 2021, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef ABSTRACT_SIMPLE_DUMP_TASK_INCLUDED
#define ABSTRACT_SIMPLE_DUMP_TASK_INCLUDED

#include "i_dump_task.h"
#include "base/atomic.h"

namespace Mysql{
namespace Tools{
namespace Dump{

/**
  Base class for all individual dump process tasks.
 */
class Abstract_simple_dump_task : public I_dump_task
{
public:
  Abstract_simple_dump_task();

  virtual ~Abstract_simple_dump_task();

  bool is_completed() const;

  virtual void set_completed();

private:
  my_boost::atomic_bool m_is_completed;
};

}
}
}

#endif

==> mysql-8.0_8.0.19.orig.tar.gz: mysql-8.0.19/client/dump/abstract_simple_dump_task.h <==
/*
  Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef ABSTRACT_SIMPLE_DUMP_TASK_INCLUDED
#define ABSTRACT_SIMPLE_DUMP_TASK_INCLUDED

#include <atomic>

#include "client/dump/i_dump_task.h"

namespace Mysql {
namespace Tools {
namespace Dump {

/**
  Base class for all individual dump process tasks.
 */
class Abstract_simple_dump_task : public I_dump_task {
 public:
  Abstract_simple_dump_task();

  virtual ~Abstract_simple_dump_task();

  bool is_completed() const;

  virtual void set_completed();

 private:
  std::atomic<bool> m_is_completed;
};

}  // namespace Dump
}  // namespace Tools
}  // namespace Mysql

#endif
